﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub FSU Set Ref Level (dBm) /9640
DATE:                  2011-01-14
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       135
CONFIGURATION:         Fluke 9640A
CONFIGURATION:         Fluke 9640A-50
=============================================================================
#
# Procedure Author:
#        DFM
#
# Model(s) Covered:
#        Rohde & Schwarz FSU series
#
# Compatibility:
#        MET/CAL 7.3.26 or later
#
# Subprocedures:
#        Sub FSU Take Sweep (MKPK)
#
# Required Files:
#        None
#
# Additional Equipment Required:
#        None
#
#  The parameters for this procedure are passed from the calling procedures.
#  Except for those identified as "Optional", all parameters are required.
#
#  @FSU_RefLvl : The desired reference level as measured by the UUT (FSU).
#  @9640Freq   : The specified 9640A output frequency in base units.
#  @9640Lvl    : The 9640A output level required to generate the specified UUT
#                reference level.
#  @9640RefOut : (Optional) The specified 9640A reference output frequency in
#                base units.
#  @9640RefIn  : (Optional) The specified 9640A reference input frequency in
#                base units.
#
#  Example(1):
# 1.001  MATH         @Error = 0
# 1.002  MATH         @TestName = "Input Attenuation Switching"
# 1.003  MATH         @FSU_RefLvl = -55; @9640Lvl = @FSU_RefLvl
# 1.004  MATH         @9640Freq = 50E+6; @9640RefOut = 10E+6
# 1.005  SCPI         CALC:MARK:Y?[I]
#
# 1.006  WHILE        ((MEM <= -0.05) || (MEM >= 0.05)) && NOT(@Error)
# 1.007  CALL         Sub FSU Set Ref Level (dBm) /9640
# 1.008  ENDW
#
# 1.009  IF           @Error
# 1.010  EVAL   -e 0 : An error occurred during the [V @TestName].
# 2.001  MATH         @Error = 0
# 2.002  END
# 2.003  ENDIF
#
#  Note: The @RefLvl and @TestLvl values MUST be stated in dBm. If it is
#  desired to establish a level using linear units, i.e., volts, see the
#  following Example(2).
#
#  Example(2):
# 1.001  MATH         @Error = 0
# 1.002  MATH         @TestName = "Input Attenuation Switching"
# 1.003  MATH         @FSU_RefLvl = -55; @9640Lvl = @FSU_RefLvl
# 1.004  MATH         @9640Freq = 50E+6; @9640RefIn = 10E+6
# 1.005  SCPI         CALC:MARK:Y?[I]
# 1.006  MATH         MEM = VTODBM(MEM, 50)
# 1.007  MATH         @CenterFreq = 50E+6; @RefLvl = 0; @TestLvl = 0
#
# 1.008  WHILE        (MEM <= -0.05) || (MEM >= 0.05) && NOT(@Error)
# 1.009  CALL         Sub FSU Set Ref Level (dBm) /9640
# 1.010  MATH         MEM = VTODBM(MEM, 50)
# 1.011  ENDW
#
# The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  MATH         @9640Lvl = @FSU_RefLvl + (@9640Lvl - MEM)

  1.002  IF           (@9640Lvl < -100) || (@9640Lvl > 20)
  1.003  OPBR         -z Error: Unable to adjust 9640A output level within
  1.003  OPBR         [32]      its operating range to achieve the desired
  1.003  OPBR         [32]      UUT test level ([V @FSU_RefLvl] dBm).
  1.003  OPBR
  1.003  OPBR         [32]      Verify UUT test requirements, 9640A output
  1.003  OPBR         [32]      limits, and connections prior to retrying,
  1.003  OPBR         [32]      if desired.
  1.003  OPBR
  1.003  OPBR         Do you wish to RETRY?
  1.003  OPBR
  1.003  OPBR         (Selecting "No" will cause the [V @TestName] test
  1.003  OPBR         to be terminated.)

  1.004  IF           MEM1
  1.005  MATH         @9640Lvl = @FSU_RefLvl
  1.006  CALL         Sub FSU Display Connection
  1.007  ELSE
  1.008  HEAD         -2
  1.009  MATH         @Error = 1
  1.010  END
  1.011  ENDIF

  1.012  ENDIF

# Select 9640A FSC depending on existence of variables that 'control' the
# 9640A REF FREQUENCY OUTPUT and REF FREQUENCY IN pased from the calling
# procedure.
  1.013  IF           NOT(ISVAR("@9640RefOut")) && ISVAR("@9640RefIn")
  1.014  9640         ExtRefFreq = [V @9640RefIn] Hz; TimebaseAccOff
  1.014  9640         OutputImp = 50 Ohms
  1.014  9640         +Level = [V @9640Lvl] dBm; Freq = [V @9640Freq] Hz
  1.015  ELSEIF       ISVAR("@9640RefOut") && NOT(ISVAR("@9640RefIn"))
  1.016  9640         OutputImp = 50 Ohms; RefFreqOutp = [V @9640RefOut] Hz
  1.016  9640         +Level = [V @9640Lvl] dBm; Freq = [V @9640Freq] Hz
  1.017  ELSEIF       ISVAR("@9640RefOut") && ISVAR("@9640RefIn")
  1.018  9640         ExtRefFreq = [V @9640RefIn] Hz; TimebaseAccOff
  1.018  9640         OutputImp = 50 Ohms; RefFreqOutp = [V @9640RefOut] Hz
  1.018  9640         +Level = [V @9640Lvl] dBm; Freq = [V @9640Freq] Hz
  1.019  ELSE
  1.020  9640         Freq = [V @9640Freq] Hz
  1.020  9640         +Level = [V @9640Lvl] dBm; OutputImp = 50 Ohms
  1.021  ENDIF

  1.022  CALL         Sub FSU Take Sweep (MKPK)
  1.023  SCPI         CALC:MARK:Y?[I]
  1.024  END
